@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.64_2';
+our $VERSION = '0.69_1'; #sexy number special
 
 # Preloaded methods go here.
 
@@ -42,7 +42,9 @@ Algorithm::Evolutionary - Perl module for performing paradigm-free evolutionary
   use Algorithm::Evolutionary qw( Op::This_Operator
                                   Individual::That_Individual
                                   Fitness::Some_Fitness); 
-  
+
+  # other modules with explicit importation
+  use Algorihtm::Evolutionary::Utils (this_util that_util);   
 
 =head1 DESCRIPTION
 
@@ -76,6 +78,8 @@ reports, news, updates, whatever.</p>
     href='https://sourceforge.net/project/showfiles.php?group_id=34080&package_id=54504'>-examples</a>
     tarballs in the file download area of that repository</p>
 
+<p>You can also get help from the <a href='https://sourceforge.net/forum/forum.php?forum_id=107255'>project forum</a> (where I usually hang around) or from <a href='mailto:opeal-help-request@lists.sourceforge.net'>the mailing list</a> (information at <a href='https://lists.sourceforge.net/lists/listinfo/opeal-help'>its web site</a>)</p>
+
 <p>I have used this continously for my research all these year, and
 any search will return a number of papers; a journal article is
 already submitted, but meanwhile if you use it for any of your
@@ -85,8 +89,13 @@ one:</p>
 =end html
 
  @InProceedings{jj:2008:PPSN,
-   author =	"Juan J. Merelo and  Antonio M. Mora and Pedro A. Castillo and Juan L. J. Laredo and Lourdes Araujo and Ken C. Sharman and Anna I. Esparcia-Alcázar and Eva Alfaro-Cid and Carlos Cotta",
-   title =	"Testing the Intermediate Disturbance Hypothesis: Effect of Asynchronous Population Incorporation on Multi-Deme Evolutionary Algorithms",
+   author =	"Juan J. Merelo and  Antonio M. Mora and Pedro A. Castillo
+                 and Juan L. J. Laredo and Lourdes Araujo and Ken C. Sharman
+                 and Anna I. Esparcia-Alczar and Eva Alfaro-Cid
+                 and Carlos Cotta",
+   title =	"Testing the Intermediate Disturbance Hypothesis: Effect of
+                 Asynchronous Population Incorporation on Multi-Deme
+                 Evolutionary Algorithms",
    booktitle =	"Parallel Problem Solving from Nature - PPSN X",
    year = 	"2008",
    editor =	"Gunter Rudolph and Thomas Jansen and Simon Lucas and
@@ -102,25 +111,36 @@ one:</p>
    doi =  	"10.1007/978-3-540-87700-4_27",
    size = 	"pages",
    notes =	"PPSN X",
-}
+ }
 
 =begin html
 
-<p>Some information on this paper and instructions from download can
+<p>Some information on this paper and instructions for downloading the code used in it can
 be found in <a
 href='http://nohnes.wordpress.com/2008/09/21/paper-on-performance-of-asynchronous-distributed-evolutionary-algorithms-available-online/'>our
 group blog</a></p> 
 
 =end html
 
+=head1 DISCUSSION, FEATURE REQUESTS
+
+Head to the CPAN forum for this module: L<http://www.cpanforum.com/dist/Algorithm-Evolutionary>
+
+=head1 BUGS?
+
+Have you found any bugs? Use the CPAN tracker to inform about them (L<http://rt.cpan.org/Public/Dist/Display.html?Name=Algorithm-Evolutionary>) or email the author (below).
+
 =head1 AUTHOR
 
 =begin html
 
-Main author and developer is J. J. Merelo, jmerelo (at)
-geneura.ugr.es. There have also been some contributions from Javi
-García, fjgc (at) decsai.ugr.es and Pedro Castillo, pedro (at)
-geneura.ugr.es. Patient users that have submitted bugs include <a
+Main author and developer is J. J. Merelo, jmerelo (at) geneura.ugr.es
+who blogs at <a href='http://blojj.blogalia.com'>BloJJ</a> and
+twitters at <a
+href='http://twitter.com/jmerelo'>twitter.com/jmerelo</a>. There have
+also been some contributions from Javi Garca, fjgc (at) decsai.ugr.es
+and Pedro Castillo, pedro (at) geneura.ugr.es. Patient users that have
+submitted bugs include <a
 href='http://barbacana.net'>jamarier</a>. Bugs, requests and any kind
 of comment are welcome.
 
@@ -129,13 +149,15 @@ of comment are welcome.
 =head1 Examples
 
 There are a few examples in the C<examples> subdirectory, which should
-have been included with your CPAN bundle. Foor instance, check out
+have been included with your CPAN bundle. For instance, check out
 C<tide_float.pl>, an example of floating point vector optimization, or
-C<run_easy_ga.pl p_peaks.yaml>, which should run an example of a
-simple GA on the P_Peaks deceptive function. 
+C<cd examples; run_easy_ga.pl p_peaks.yaml>, which should run an
+    example of a
+simple GA on the P_Peaks deceptive function.
 
-Some other examples are installed: check out L<tide_bitstring.pl>, L<tide_float.pl> and L<canonical-genetic-algorithm.pl>, 
-which you can run and play with to get a taste of what EA programming is like. 
+Some other examples are installed: check out L<tide_bitstring.pl>,
+    L<tide_float.pl> and L<canonical-genetic-algorithm.pl>,
+which you can run and play with to get a taste of what EA programming is like, and then ammend, add and modify at leisure to create your own evolutionary algorithms. 
 
 =head1 SEE ALSO
 
@@ -149,13 +171,18 @@ which you can run and play with to get a taste of what EA programming is like.
 
 =item L<Algorithm::Evolutionary::Experiment>.
 
+=item L<Algorithm::Evolutionary::Run>.
+
+=item L<Algorithm::Evolutionary::Op::CanonicalGA>.
+
 =item L<XML> for an explanation of the XML format used
 
 =item L<POE::Component::Algorithm::Evolutionary> if you want to mix
 evolutionary algorithms with anything else easily
 
-You might be interested in one of the other GA modules out there, such
-as L<AI::Genetic::Pro> 
+You might also be interested in one of the other perl GA and
+evolutionary computation modules out there, such as
+L<AI::Genetic::Pro>
 
 =back 
 
@@ -166,10 +193,9 @@ as L<AI::Genetic::Pro>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/11 12:38:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 2.7 2009/02/11 12:38:14 jmerelo Exp $ 
+  CVS Info: $Date: 2009/07/24 12:58:45 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.2 2009/07/24 12:58:45 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.7 $
-  $Name $
+  $Revision: 3.2 $
 
 =cut
